/*
 *    Copyright (c) 2009 Nicolas MARTIGNOLE
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 *    See http://touilleur-express.fr Le Touilleur Express, blog about Java.
 */

package com.innoteria;

import javax.mail.Message;
import javax.mail.MessagingException;
import java.io.Serializable;
import java.io.IOException;

/**
 * I wrote this Adapter class that is Serializable for Wicket because javax.mail.internet.MimeMessage
 * is not serializable and thus cannot be rendered in the view.
 *
 * @author Nicolas Martignole
 * @Adapter (from="javax.mail.Message")
 */
public class InnoteriaMessage implements Serializable {
    private String subject;
    private String content;
    private String from;

    public InnoteriaMessage(Message m) {
        try {
            this.subject = m.getSubject();
        } catch (MessagingException e) {
            this.subject = "Invalid subject";
        }
        try {
            this.content = (String) m.getContent();
        } catch (IOException e) {
            this.content = "Invalid content";
        } catch (MessagingException e) {
            this.content = "Invalid content 2";
        }
        try {
            this.from = m.getFrom()[0].toString(); // really dirty
        } catch (MessagingException e) {
            this.from = "Invalid from";
        }
    }

    public String getContent() {
        return content;
    }

    public String getFrom() {
        return from;
    }

    public String getSubject() {
        return subject;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        InnoteriaMessage that = (InnoteriaMessage) o;

        if (content != null ? !content.equals(that.content) : that.content != null) return false;
        if (from != null ? !from.equals(that.from) : that.from != null) return false;
        if (subject != null ? !subject.equals(that.subject) : that.subject != null) return false;

        return true;
    }

    @Override
    public int hashCode() {
        int result = subject != null ? subject.hashCode() : 0;
        result = 31 * result + (content != null ? content.hashCode() : 0);
        result = 31 * result + (from != null ? from.hashCode() : 0);
        return result;
    }

    @Override
    public String toString() {
        return "InnoteriaMessage{" +
                "content='" + content + '\'' +
                ", subject='" + subject + '\'' +
                ", from='" + from + '\'' +
                '}';
    }
}
