/*
 *    Copyright (c) 2009 Nicolas MARTIGNOLE
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 *    See http://touilleur-express.fr Le Touilleur Express, blog about Java.
 */

package com.innoteria;


import org.apache.camel.component.file.FileComponent;


import org.apache.camel.builder.RouteBuilder;

/**
  * Generates an email from in-memory queue using Velocity template,
 * Stores this email in a folder
 *
 * Then another service polls this folder, add an email header
 * and send to smpt server the generated email
 *
 * @author Nicolas Martignole
 */
public class ReportIncidentRoutes extends RouteBuilder {

    public void configure() throws Exception {
        // Route 1 :
        // load from in memory queue, call a velocity template
        // then store on the local file system the email
        from("direct:start")
            .to("velocity:MailBody.vm")
                .setHeader(FileComponent.HEADER_FILE_NAME, "errorEmail.txt")
                .to("file:///./target/demoCamel?append=false");

        // Load from a folder, add an email suject then
        // send everything to the outgoing SMTP server,
        // I have a MailBox (java mock mail) started from my
        // main wicket application, so there's something listening
        // on port 25 :-) 
        from("file:///./target/demoCamel")
            .setHeader("subject", constant("New incident reported"))
           .to("smtp://nicolas@localhost?password=secret&to=incident@innoteria.fr");

        
        /*
        ANOTHER Sample to give you an idea of stuff  we can do with Camel
        and that's harder to do with Mule 

        from("queue:a").filter(header("foo").isEqualTo("bar")).to("queue:b");
        
        from("queue:c").choice()
                .when(header("foo").isEqualTo("bar")).to("queue:d")
                .when(header("foo").isEqualTo("cheese")).to("queue:e")
                .otherwise().to("queue:f");

         */
    }

}